=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2013-10-04 09:56:23 +0000
+++ bzrlib/errors.py	2016-01-27 13:36:17 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2011 Canonical Ltd
+# Copyright (C) 2005-2013, 2016 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -1686,14 +1686,6 @@
         TransportError.__init__(self, msg, orig_error=orig_error)
 
 
-class CertificateError(TransportError):
-
-    _fmt = "Certificate error: %(error)s"
-
-    def __init__(self, error):
-        self.error = error
-
-
 class InvalidHttpRange(InvalidHttpResponse):
 
     _fmt = "Invalid http range %(range)r for %(path)s: %(msg)s"

=== modified file 'bzrlib/tests/test_https_urllib.py'
--- bzrlib/tests/test_https_urllib.py	2013-05-20 16:38:11 +0000
+++ bzrlib/tests/test_https_urllib.py	2016-01-27 13:36:17 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2011,2012 Canonical Ltd
+# Copyright (C) 2011, 2012, 2013, 2016 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,15 +24,14 @@
 from bzrlib import (
     config,
     trace,
-    )
+)
 from bzrlib.errors import (
-    CertificateError,
     ConfigOptionValueError,
-    )
+)
 from bzrlib.tests import (
     TestCase,
     TestCaseInTempDir,
-    )
+)
 from bzrlib.transport.http import _urllib2_wrappers
 
 
@@ -58,6 +57,7 @@
         self.overrideAttr(_urllib2_wrappers.opt_ssl_ca_certs, 'default',
                           os.path.join(self.test_dir, u"nonexisting.pem"))
         self.warnings = []
+
         def warning(*args):
             self.warnings.append(args[0] % args[1:])
         self.overrideAttr(trace, 'warning', warning)
@@ -86,31 +86,30 @@
 
     def test_no_certificate(self):
         self.assertRaises(ValueError,
-                          _urllib2_wrappers.match_hostname, {}, "example.com")
+                          ssl.match_hostname, {}, "example.com")
 
     def test_wildcards_in_cert(self):
         def ok(cert, hostname):
-            _urllib2_wrappers.match_hostname(cert, hostname)
+            ssl.match_hostname(cert, hostname)
+
+        def not_ok(cert, hostname):
+            self.assertRaises(
+                ssl.CertificateError,
+                ssl.match_hostname, cert, hostname)
 
         # Python Issue #17980: avoid denials of service by refusing more than
         # one wildcard per fragment.
-        cert = {'subject': ((('commonName', 'a*b.com'),),)}
-        ok(cert, 'axxb.com')
-        cert = {'subject': ((('commonName', 'a*b.co*'),),)}
-        ok(cert, 'axxb.com')
-        cert = {'subject': ((('commonName', 'a*b*.com'),),)}
-        try:
-            _urllib2_wrappers.match_hostname(cert, 'axxbxxc.com')
-        except ValueError as e:
-            self.assertIn("too many wildcards", str(e))
+        ok({'subject': ((('commonName', 'a*b.com'),),)}, 'axxb.com')
+        not_ok({'subject': ((('commonName', 'a*b.co*'),),)}, 'axxb.com')
+        not_ok({'subject': ((('commonName', 'a*b*.com'),),)}, 'axxbxxc.com')
 
     def test_no_valid_attributes(self):
-        self.assertRaises(CertificateError, _urllib2_wrappers.match_hostname,
+        self.assertRaises(ssl.CertificateError, ssl.match_hostname,
                           {"Problem": "Solved"}, "example.com")
 
     def test_common_name(self):
         cert = {'subject': ((('commonName', 'example.com'),),)}
         self.assertIs(None,
-                      _urllib2_wrappers.match_hostname(cert, "example.com"))
-        self.assertRaises(CertificateError, _urllib2_wrappers.match_hostname,
+                      ssl.match_hostname(cert, "example.com"))
+        self.assertRaises(ssl.CertificateError, ssl.match_hostname,
                           cert, "example.org")

=== modified file 'bzrlib/transport/http/_urllib2_wrappers.py'
--- bzrlib/transport/http/_urllib2_wrappers.py	2013-05-20 16:38:11 +0000
+++ bzrlib/transport/http/_urllib2_wrappers.py	2016-01-27 13:36:17 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2012 Canonical Ltd
+# Copyright (C) 2006-2013, 2016 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -398,68 +398,6 @@
         self._wrap_socket_for_reporting(self.sock)
 
 
-# These two methods were imported from Python 3.2's ssl module
-
-def _dnsname_to_pat(dn, max_wildcards=1):
-    pats = []
-    for frag in dn.split(r'.'):
-        if frag.count('*') > max_wildcards:
-            # Python Issue #17980: avoid denials of service by refusing more
-            # than one wildcard per fragment.  A survery of established
-            # policy among SSL implementations showed it to be a
-            # reasonable choice.
-            raise ValueError(
-                "too many wildcards in certificate DNS name: " + repr(dn))
-        if frag == '*':
-            # When '*' is a fragment by itself, it matches a non-empty dotless
-            # fragment.
-            pats.append('[^.]+')
-        else:
-            # Otherwise, '*' matches any dotless fragment.
-            frag = re.escape(frag)
-            pats.append(frag.replace(r'\*', '[^.]*'))
-    return re.compile(r'\A' + r'\.'.join(pats) + r'\Z', re.IGNORECASE)
-
-
-def match_hostname(cert, hostname):
-    """Verify that *cert* (in decoded format as returned by
-    SSLSocket.getpeercert()) matches the *hostname*.  RFC 2818 rules
-    are mostly followed, but IP addresses are not accepted for *hostname*.
-
-    CertificateError is raised on failure. On success, the function
-    returns nothing.
-    """
-    if not cert:
-        raise ValueError("empty or no certificate")
-    dnsnames = []
-    san = cert.get('subjectAltName', ())
-    for key, value in san:
-        if key == 'DNS':
-            if _dnsname_to_pat(value).match(hostname):
-                return
-            dnsnames.append(value)
-    if not san:
-        # The subject is only checked when subjectAltName is empty
-        for sub in cert.get('subject', ()):
-            for key, value in sub:
-                # XXX according to RFC 2818, the most specific Common Name
-                # must be used.
-                if key == 'commonName':
-                    if _dnsname_to_pat(value).match(hostname):
-                        return
-                    dnsnames.append(value)
-    if len(dnsnames) > 1:
-        raise errors.CertificateError(
-            "hostname %r doesn't match either of %s"
-            % (hostname, ', '.join(map(repr, dnsnames))))
-    elif len(dnsnames) == 1:
-        raise errors.CertificateError("hostname %r doesn't match %r" %
-                                      (hostname, dnsnames[0]))
-    else:
-        raise errors.CertificateError("no appropriate commonName or "
-            "subjectAltName fields were found")
-
-
 class HTTPSConnection(AbstractHTTPConnection, httplib.HTTPSConnection):
 
     def __init__(self, host, port=None, key_file=None, cert_file=None,
@@ -515,7 +453,7 @@
             raise
         if cert_reqs == ssl.CERT_REQUIRED:
             peer_cert = ssl_sock.getpeercert()
-            match_hostname(peer_cert, host)
+            ssl.match_hostname(peer_cert, host)
 
         # Wrap the ssl socket before anybody use it
         self._wrap_socket_for_reporting(ssl_sock)
@@ -833,7 +771,7 @@
                     % (request, request.connection.sock.getsockname())
             response = connection.getresponse()
             convert_to_addinfourl = True
-        except (ssl.SSLError, errors.CertificateError):
+        except (ssl.SSLError, ssl.CertificateError):
             # Something is wrong with either the certificate or the hostname,
             # re-trying won't help
             raise

